@@ -22,9 +22,13 @@ class TestExamples(TestBase):
 			assert ldb.has_object(oinfo.binsha)
 		# END for each sha in database
 		# assure we close all files
-		del(ostream)
-		del(oinfo)
-		
+		try:
+			del(ostream)
+			del(oinfo)
+		except UnboundLocalError:
+			pass
+		# END ignore exception if there are no loose objects
+			
 		data = "my data"
 		istream = IStream("blob", len(data), StringIO(data))
 		
